package com.ruoyi.system.service.impl;

import cn.hutool.core.util.IdUtil;
import com.ruoyi.common.core.domain.entity.MusicScene;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.mapper.MusicSceneMapper;
import com.ruoyi.system.service.IMusicSceneService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@Service
public class MusicSceneServiceImpl implements IMusicSceneService 
{
    @Autowired
    private MusicSceneMapper musicSceneMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public MusicScene selectMusicSceneById(String id)
    {
        return musicSceneMapper.selectMusicSceneById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param musicScene 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<MusicScene> selectMusicSceneList(MusicScene musicScene)
    {
        return musicSceneMapper.selectMusicSceneList(musicScene);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param musicScene 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertMusicScene(MusicScene musicScene)
    {
        musicScene.setCreateTime(DateUtils.getNowDate());
        musicScene.setSceneId(IdUtil.getSnowflakeNextId());
        musicScene.setCreator(SecurityUtils.getUsername());
        return musicSceneMapper.insertMusicScene(musicScene);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param musicScene 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateMusicScene(MusicScene musicScene)
    {
        musicScene.setUpdateTime(DateUtils.getNowDate());
        return musicSceneMapper.updateMusicScene(musicScene);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteMusicSceneByIds(String[] ids)
    {
        return musicSceneMapper.deleteMusicSceneByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteMusicSceneById(String id)
    {
        return musicSceneMapper.deleteMusicSceneById(id);
    }
}
